
Distinguish log-fields from trusted and untrusted sources
-------

**Description:**

Whenever log fields are distinguished from each other by means of logs from trusted and 
untrusted log fields in your log entries your logs become clearer and more transparent.


**Solution:**

Verify that log fields from trusted and untrusted sources are distinguishable in 
log entries.
